# Angular + Bryntum Scheduler Wrapper - Test Harness

This example uses Bryntum Scheduler wrapped in the provided BryntumSchedulerComponent wrapper.

The purpose of this test harness is to allow you to update the bundled Bryntum version via the package.json
to test basic features that we utilize within Audere, so that we can identify any potential issues prior to integrating into the Audere codebase.
As we have seen in the past, once we integrate, the complexity increases and identifying where the issue is becomes much more time consuming and costly.

Over time, as we continue our integration and dependency on Bryntum, this test harness should evolve to include those features and functionality that Audere leverages.

## Some Objectives to Keep In Mind

-   KISS is important - Keep It Super Simple
-   Focus on the features that Audere utilizes, not the full use of them.
-   Styling is not the focus

## Main Features of Bryntum Scheduler Utilized

-   Drag Create
-   Drag Resize (contract & expand)
-   Drag Move
-   Infinite Scroll
-   View Presets for Day, Week, Month with custom renderers (based on that in Audere, but simplified)
-   ScrollToNow
-   Row Reorder
-   EventRender - Assignment (HourEntry), Project and Phase (Task)

## Things to Note

-   This project was generated with [Angular CLI](https://github.com/angular/angular-cli) v13 as it's based on Bryntum's Angular Examples.
-   Bryntum DateHelper is used vs third-party libraries like moment or date-fns.
-   Bryntum Angular Wrapper was used in favor of pulling in our custom implementation of the wrapper. Our implementation is complex and is specific to our codebase, distracting from the intent of this Test Harness.
-   There is little to no business logic to replicate that found in Audere, to minimize complexity and not re-create Audere.
-   scheduler2 route and associated view is not currently used and was left for potential future use.

## Why Use the Angular Wrapper?

-   While the Audere implementation of the scheduler doesn't yet leverage the Angular Wrapper provided by Bryntum, it greatly simplifies the use of the component within an Angular application.
-   The Audere wrapper implementation is loosly based on the Bryntum Angular Wrapper.
-   Long-term, Audere will transition to use the Bryntum Angular Wrapper.
-   Using it cuts down on 1000's of lines of implementation code that has largely never been an issue in the past, specific to Bryntum, allowing this test harness to remain simplified and abstract from Audere.

# Next Steps

The following are things to consider next for integrating into this test harness:

-   Integrate Automated Tests using Playwright
-   Build out the "Audere Scheduler" view to allow you to drop in the downloadTestCase app.js file and extract the config from it and instantiate a Scheduler based on that config.
-   Develop a mechanism for triggering an automated build upon new Bryntum releases.
-   Integrate performance testing
-   Develop scripts to generate large datasets for use in performance testings.

# Upgrading this Test Harness to the Latest Bryntum

-   You will either need to make sure that you have the Bryntum Private Repo access setup (detailed below) or upgrade our internal bryntum-scheduler repo to the latest Bryntum source.
-   Once one of the above is complete, you should be able to simply update the bryntum versions in the package.json

# Bryntum Repository access setup

**IMPORTANT NOTE!** These access instructions are mandatory when using the private Bryntum NPM repository.

This example uses npm packages from the Bryntum private NPM repository. You must be logged-in to this repository as a
licensed or trial user to access the packages. Please
check [Online npm repository guide](https://bryntum.com/docs/scheduler/guide/Scheduler/npm-repository) for detailed information
on the sign-up/login process. Also you can check bundled guide inside distribution zip
in `docs/guides/npm-repository.md`.

# Installation

Use the following command to install the example packages after the successful login.

```shell
$ npm install
```

# Running a development server

To build example and start development server run this command:

```shell
$ npm run start
```

Navigate to `http://localhost:4200/` or `http://127.0.0.1:4200/` in your browser. We recommend to use latest versions of
modern browsers like Chrome, FireFox, Safari or Edge (Chromium). The app will automatically reload if you change any of
the source files.

-   Once launched, you can use the default view (Projects)
-   This view allows you to test the tree / nesting of scheduler resources and their associated events.
-   You can use the Today button to jump to the current day within the scheduler, which will default to being centered.
-   The timeline view buttons (Day, Week, Month) will change the viewPreset based on a simple implementation of that used in Audere.

# Creating a production build

To build production code for the example run this command:

Using **npm**:

```shell
$ npm run build
```

Using **yarn**:

```shell
$ yarn run build
```

The build artifacts will be stored in the `dist/` directory.

# Distribution zip references

-   Bryntum API docs. Open `docs/index.html` in your browser.
-   Bryntum Repository guide `docs/guides/npm-repository.md`.
-   Bryntum Angular integration guide `docs/guides/integration/angular.md`.

# Online References

-   [Angular Framework](https://angular.io)
-   [Bryntum Angular integration guide](https://bryntum.com/docs/scheduler/guide/Scheduler/integration/angular)
-   [Bryntum Scheduler documentation](https://bryntum.com/docs/scheduler/)
-   [Bryntum Scheduler examples](https://bryntum.com/examples/scheduler/)
-   [Bryntum npm repository guide](https://bryntum.com/docs/scheduler/guide/Scheduler/npm-repository)
-   [Bryntum support Forum](https://bryntum.com/forum/)
-   [Contacts us](https://bryntum.com/contact/)
