import { APIRequestContext, test as base } from '@playwright/test';
import { MetricReporter } from './metric-reporter';

export const test = base.extend<
    {
        captureMetrics: string[];
        metrics: MetricReporter;
        clearMetrics: () => Promise<void>;
    },
    {}
>({
    captureMetrics: [[], { option: true }],
    contextOptions: async ({ contextOptions }, use) => {
        contextOptions.recordHar = {
            path: test.info().outputPath('network.har'),
        };

        await use(contextOptions);

        await test.info().attach('network', {
            path: contextOptions.recordHar.path,
            contentType: 'application/json',
        });
    },
    metrics: async ({ playwright, page, captureMetrics }, use) => {
        const apiContext: APIRequestContext =
            await playwright.request.newContext();

        await use(
            new MetricReporter(
                apiContext,
                page,
                captureMetrics,
                process.env.BuildId ?? 'local',
                process.env.Branch ?? 'local'
            )
        );

        await apiContext.dispose();
    },

    clearMetrics: async ({ page }, use) => {
        await use(async (): Promise<void> => {
            await page.evaluate(() => {
                performance.clearMarks();
                performance.clearMeasures();
                performance.clearResourceTimings();
            });
        });
    },
});
