import { expect, APIRequestContext, Page } from '@playwright/test';
import * as os from 'os';

export class MetricReporter {
    constructor(
        private readonly context: APIRequestContext,
        private readonly page: Page,
        private readonly captureMetrics: string[],
        private readonly buildId: string,
        private readonly branch: string
    ) {}

    async report(
        assignmentCount: number,
        opts: {
            name: string;
            value: number;
            expectedValue: number;
        }
    ): Promise<void> {
        const data: {
            Build: string;
            BuildDate: string;
            Branch: string;
            AssignmentCount: number;
            MetricName: string;
            SubMetricName?: string;
            MetricValue: number;
            ExpectedMetricValue?: number;
            UserName: string;
        }[] = [];

        const date = new Date().toISOString();

        data.push({
            Build: this.buildId,
            BuildDate: date,
            Branch: this.branch,
            AssignmentCount: assignmentCount,
            MetricName: opts.name,
            MetricValue: opts.value,
            ExpectedMetricValue: opts.expectedValue,
            UserName: os.userInfo().username,
        });

        console.log(data[0]);

        for (const subMetric of this.captureMetrics) {
            const metric = await this.getMetrics(subMetric);

            console.log(metric);

            data.push({
                Build: this.buildId,
                BuildDate: date,
                Branch: this.branch,
                AssignmentCount: assignmentCount,
                MetricName: opts.name,
                SubMetricName: subMetric,
                MetricValue: metric.data?.duration,
                UserName: os.userInfo().username,
            });
        }

        const response = await this.context.post(
            // eslint-disable-next-line max-len
            'https://api.powerbi.com/beta/a8a719dc-348d-46ef-b888-fa1832eaac47/datasets/858d1774-ab01-4f06-b823-153d013e6d54/rows?key=V4r8zoX3xGZhIQekeqJKO%2FG3a1kZW95U0LV6ZsVCq1aCCfCn5sD2KZalr0yl5VyJNNb4NFgEcmpNCR0Rkh%2B4nQ%3D%3D',
            {
                data: data,
            }
        );

        console.log(await response.text());

        await expect(response).toBeOK();

        expect(opts.value, opts.name).toBeLessThan(opts.expectedValue);
    }

    private async getMetrics(entryName: string): Promise<{
        data: PerformanceMeasure;
    }> {
        return JSON.parse(
            await this.page.evaluate((entryName) => {
                const [timing] = performance.getEntriesByName(entryName);
                return JSON.stringify({
                    data: timing,
                });
            }, entryName)
        );
    }
}
