import { BrowserContext } from '@playwright/test';
import { addHours } from 'date-fns';
import { Data } from './data';

export const useMockData = (
    context: BrowserContext,
    data: Data
): Promise<void> =>
    context.route('https://appdev.bstdevhorizon.com/api/**', (route) => {
        const method = route.request().method();
        const url = route.request().url();

        if (
            method === 'GET' &&
            url === 'https://appdev.bstdevhorizon.com/api/v1/tenants'
        ) {
            void route.fulfill({
                body: JSON.stringify([
                    {
                        id: data.tenant.id,
                        name: data.tenant.name,
                        user: {
                            userId: data.tenant.user.userId,
                            personId: data.tenant.user.personId,
                            invitedAs: 'Owner',
                            status: 'Active',
                            userPreferences: {
                                theme: 0,
                                filters: {
                                    roleIds: [],
                                    clientIds: [],
                                    chargeable: [false, false],
                                    projectIds: [],
                                    assigneeIds: [],
                                    projectStatuses: ['Confirmed', 'Tentative'],
                                    assigneeStatuses: ['Active'],
                                },
                                paddingTheme: 0,
                                scheduleView: 0,
                                hideEmptyRows: false,
                                enableAnimation: true,
                                scheduleTimeline: 'day',
                                scheduleColumnPreferences: [
                                    { name: 'name', width: 356 },
                                    { name: 'hours', width: 65 },
                                ],
                            },
                        },
                        assignee: data.tenant.assignee,
                        mfaRequired: false,
                        subscription: {
                            status: 'Active',
                            trialStart: null,
                            trialEnd: null,
                        },
                    },
                ]),
            });
        } else if (
            method == 'POST' &&
            url ===
                'https://appdev.bstdevhorizon.com/api/v1.1/assignments/preview'
        ) {
            void route.fulfill({
                body: JSON.stringify(data.assignments),
            });
        } else if (
            method === 'GET' &&
            url === 'https://appdev.bstdevhorizon.com/api/v1/working-calendars/'
        ) {
            void route.fulfill({
                body: JSON.stringify([
                    {
                        id: '7d6de10a-a16c-43f9-96ca-53b932390753',
                        tenantId: data.tenant.id,
                        name: 'Default',
                        hoursMonday: 8,
                        hoursTuesday: 8,
                        hoursWednesday: 8,
                        hoursThursday: 8,
                        hoursFriday: 8,
                        hoursSaturday: 0,
                        hoursSunday: 0,
                    },
                ]),
            });
        } else if (
            method === 'GET' &&
            url ===
                'https://appdev.bstdevhorizon.com/api/v1/working-calendar-settings'
        ) {
            void route.fulfill({
                body: JSON.stringify({
                    id: '5dae8115-805f-4094-b7ce-f8d84cc63f08',
                    tenantId: data.tenant.id,
                    defaultWorkingCalendarId:
                        '7d6de10a-a16c-43f9-96ca-53b932390753',
                    firstDayOfWeek: 'Sunday',
                }),
            });
        } else if (
            method === 'GET' &&
            url === 'https://appdev.bstdevhorizon.com/api/v1/clients'
        ) {
            void route.fulfill({
                body: JSON.stringify({
                    elements: data.clients,
                    sortToken: `${data.clients[data.clients.length - 1].name}${
                        data.clients[data.clients.length - 1].id
                    }`,
                }),
            });
        } else if (
            method === 'GET' &&
            url === 'https://appdev.bstdevhorizon.com/api/v1/roles'
        ) {
            void route.fulfill({
                body: JSON.stringify(data.roles),
            });
        } else if (
            method === 'GET' &&
            url === 'https://appdev.bstdevhorizon.com/api/v1/projects'
        ) {
            void route.fulfill({
                body: JSON.stringify({
                    elements: data.projects,
                    sortToken: `${
                        data.projects[data.projects.length - 1].name
                    }${data.projects[data.projects.length - 1].id}`,
                }),
            });
        } else if (
            method === 'GET' &&
            url === 'https://appdev.bstdevhorizon.com/api/v1/assignees'
        ) {
            void route.fulfill({
                body: JSON.stringify({
                    elements: data.assignees,
                    sortToken: `${
                        data.assignees[data.assignees.length - 1].name
                    }${data.assignees[data.assignees.length - 1].id}`,
                }),
            });
        } else if (
            method === 'GET' &&
            url ===
                'https://appdev.bstdevhorizon.com/api/v1/tenants/signed-asset-url'
        ) {
            void route.fulfill({
                body: JSON.stringify({
                    signedUrl: `https://localhost:4200/userassets/tenants/${data.tenant.id}/`,
                    keyExpirationTime: addHours(new Date(), 1).toISOString(),
                }),
            });
        } else if (
            method === 'POST' &&
            url ===
                'https://appdev.bstdevhorizon.com/api/v1.1/association-summaries/preview'
        ) {
            void route.fulfill({
                body: JSON.stringify(data.associationSummaries),
            });
        } else if (
            method === 'POST' &&
            url === 'https://appdev.bstdevhorizon.com/api/v1/assignments/filter'
        ) {
            void route.fulfill({
                body: JSON.stringify({
                    elements: data.assignments,
                    sortToken: null,
                }),
            });
        } else if (
            method === 'POST' &&
            url ===
                'https://appdev.bstdevhorizon.com/api/v1/association-summaries/filter'
        ) {
            void route.fulfill({
                body: JSON.stringify({
                    elements: data.associationSummaries,
                    sortToken: null,
                }),
            });
        } else if (
            method === 'PUT' &&
            url ===
                `https://appdev.bstdevhorizon.com/api/v1/tenants/${data.tenant.id}/userpreferences/${data.tenant.user.userId}`
        ) {
        } else {
            throw new Error(`Unhandled Mock Route: ${method} ${url}`);
        }
    });
