import { test } from '../fixture';
import { Data } from '../data';
import { useMockData } from '../router';
import * as fns from 'date-fns';

const scenarios: {
    expect: {
        initialLoad: number;
        dayToMonth: number;
    };
    data: Data;
}[] = [
    {
        expect: {
            initialLoad: 9000,
            dayToMonth: 4000,
        },
        data: new Data({
            clientCount: 25,
            roleCount: 10,
            peopleCount: 25,
            projectCount: 25,
            maxTasksPerProject: 3,
            associationCount: 130,
            maxAssignmentCountPerAssociation: 7,
            assignmentStartDateOffset: { min: -90, max: 45 },
            assignmentEndDateOffset: { min: 0, max: 45 },
        }),
    },
    {
        expect: {
            initialLoad: 10000,
            dayToMonth: 5000,
        },
        data: new Data({
            clientCount: 25,
            roleCount: 10,
            peopleCount: 25,
            projectCount: 25,
            maxTasksPerProject: 3,
            associationCount: 500,
            maxAssignmentCountPerAssociation: 6,
            assignmentStartDateOffset: { min: -90, max: 45 },
            assignmentEndDateOffset: { min: 0, max: 45 },
        }),
    },
    {
        expect: {
            initialLoad: 12000,
            dayToMonth: 8000,
        },
        data: new Data({
            clientCount: 25,
            roleCount: 10,
            peopleCount: 25,
            projectCount: 25,
            maxTasksPerProject: 3,
            associationCount: 1000,
            maxAssignmentCountPerAssociation: 6,
            assignmentStartDateOffset: { min: -90, max: 45 },
            assignmentEndDateOffset: { min: 0, max: 45 },
        }),
    },
    {
        expect: {
            initialLoad: 35000,
            dayToMonth: 12000,
        },
        data: new Data({
            clientCount: 25,
            roleCount: 10,
            peopleCount: 25,
            projectCount: 25,
            maxTasksPerProject: 3,
            associationCount: 2000,
            maxAssignmentCountPerAssociation: 6,
            assignmentStartDateOffset: { min: -90, max: 45 },
            assignmentEndDateOffset: { min: 0, max: 45 },
        }),
    },
    {
        expect: {
            initialLoad: 29000,
            dayToMonth: 17000,
        },
        data: new Data({
            clientCount: 25,
            roleCount: 10,
            peopleCount: 25,
            projectCount: 25,
            maxTasksPerProject: 3,
            associationCount: 4000,
            maxAssignmentCountPerAssociation: 5,
            assignmentStartDateOffset: { min: -180, max: 180 },
            assignmentEndDateOffset: { min: 0, max: 180 },
        }),
    },
];

test.use({
    captureMetrics: [
        'setupTimeline',
        'bryntum::eventRenderer',
        'baseScheduler::ngOnChanges',
        'dispatchResourcesChange',
        'baseScheduler::ngOnInit',
        'scheduleComponent::whenProjectReady',
    ],
});

test.describe('Initial Load', () => {
    let i = 1;
    for (const scenario of scenarios) {
        test(`${i++}) ${scenario.data.assignments.length} Assignments`, async ({
            context,
            browser,
            page,
            metrics,
            clearMetrics,
        }, testInfo) => {
            await useMockData(context, scenario.data);

            await page.goto('/scheduler1');

            // await page
            //   .locator('input:near(:text-is("Email"))')
            //   .first()
            //   .type('Tenant1_Role1_1@bstglobal.com');
            // await page
            //   .locator('input:near(:text-is("Password"))')
            //   .first()
            //   .type('fzq$L6EsFH8');

            // await page.locator(':text("Sign In")').click({ trial: true });

            await browser.startTracing(page, {
                path: testInfo.outputDir + '/chrome-trace.json',
                screenshots: true,
            });

            await clearMetrics();

            const beforeAction = new Date();

            // await page.locator(':text("Sign In")').click();
            //
            // await page
            //   .locator('data-testid=add-person-project-menu')
            //   .click({ trial: true });

            const afterAction = new Date();

            await browser.stopTracing();

            await testInfo.attach('chrome-trace', {
                path: testInfo.outputDir + '/chrome-trace.json',
                contentType: 'application/json',
            });

            // await metrics.report(scenario.data.assignments.length, {
            //   name: 'Sign In and Initial Load',
            //   value: fns.differenceInMilliseconds(afterAction, beforeAction),
            //   expectedValue: scenario.expect.initialLoad,
            // });
        });
    }
});
