/**
 * Angular advanced demo app module
 */
import { BrowserModule } from '@angular/platform-browser';
import { NgModule, ErrorHandler, Injector } from '@angular/core';
import { AppErrorHandler } from './error.handler';
import { StoreModule } from '@ngrx/store';
import { createCustomElement } from '@angular/elements';

import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import { Scheduler1Component } from './scheduler1/scheduler1.component';
import { AudereSchedulerComponent } from './audere-scheduler/audere-scheduler.component';
import { RouteReuseStrategy } from '@angular/router';
import { MyReuseStrategy } from './router/my-reuse-strategy';
import { barMarginReducer } from './store/app.reducer';
import { BryntumSchedulerProModule } from '@bryntum/schedulerpro-angular';
import { AssignmentComponent } from './components/assignment/assignment.component';
import { ProjectComponent } from './components/project/project.component';
import { PhaseComponent } from './components/phase/phase.component';

@NgModule({
    declarations: [
        AppComponent,
        Scheduler1Component,
        AssignmentComponent,
        AudereSchedulerComponent,
        ProjectComponent,
        PhaseComponent,
    ],
    entryComponents: [AssignmentComponent],
    imports: [
        BrowserModule,
        AppRoutingModule,
        BryntumSchedulerProModule,
        StoreModule.forRoot({
            barMargin: barMarginReducer,
        }),
    ],
    providers: [
        { provide: RouteReuseStrategy, useClass: MyReuseStrategy },
        { provide: ErrorHandler, useClass: AppErrorHandler },
    ],
    bootstrap: [AppComponent],
})
export class AppModule {
    constructor(injector: Injector) {
        customElements.define(
            'hz-assignment',
            createCustomElement(AssignmentComponent, { injector })
        );
        customElements.define(
            'hz-project',
            createCustomElement(ProjectComponent, { injector })
        );
        customElements.define(
            'hz-phase',
            createCustomElement(PhaseComponent, { injector })
        );
    }
}
