import {
    AfterViewInit,
    Component,
    ElementRef,
    OnInit,
    ViewChild,
} from '@angular/core';

@Component({
    selector: 'app-audere-scheduler',
    templateUrl: './audere-scheduler.component.html',
    styleUrls: ['./audere-scheduler.component.scss'],
})
export class AudereSchedulerComponent implements OnInit, AfterViewInit {
    public fileDropped: boolean = false;

    constructor() {}
    @ViewChild('droponme') dropTarget: ElementRef<HTMLDivElement>;
    @ViewChild('droppedfile') droppedFileInfo: ElementRef<HTMLDivElement>;

    ngOnInit(): void {}

    ngAfterViewInit(): void {
        this.dropTarget.nativeElement.addEventListener(
            'drop',
            (event) => {
                event.preventDefault();
                const fileList = event.dataTransfer.files;

                if (!fileList) return;

                if (fileList.length > 1) {
                    console.error('Only one file can be selected.');
                    return;
                } else {
                    const currentFile = fileList[0];
                    this.droppedFileInfo.nativeElement.innerHTML += `${currentFile.name}`;

                    this.dropTarget.nativeElement.classList.add('dropped');

                    const fileReader = new FileReader();

                    fileReader.readAsText(currentFile);

                    fileReader.onloadend = (event) => {
                        console.log('loading complete.');
                        console.log(fileReader.result);
                        const resultString: string =
                            fileReader.result as string;
                        const fileLines = resultString.split('\n');

                        // Just making sure we've parsed the file and can read the contents.
                        console.log('filelines:', fileLines[4]);

                        // TODO: Extract the configuration and data from the dropped app.js
                        // by stripping out the non-json related file content.
                        // One challenge with this is that we use custom validators
                        // that reference third-party libraries, date-fns being one of those.
                        // We need to remove these manually before we import the file
                        // or we need to scan the parsed input and strip these validators out
                        // before we instantiate the scheduler.

                        this.fileDropped = true;
                    };
                }
            },
            false
        );

        this.dropTarget.nativeElement.addEventListener(
            'dragover',
            (event) => {
                event.preventDefault();
            },
            false
        );
    }

    public resetDropZone(): void {
        console.log('resetDropZone');
        this.droppedFileInfo.nativeElement.innerHTML = '';
        this.dropTarget.nativeElement.classList.remove('dropped');
        this.fileDropped = false;
    }

    public proceed(): void {
        console.log('proceed....');
    }
}
