/**
 * Scheduler 1 config file
 */

import { SchedulerProConfig } from '@bryntum/schedulerpro';

export const scheduler1Config: Partial<SchedulerProConfig> = {
    infiniteScroll: true,
    eventColor: 'null',
    eventSelectionDisabled: false,
    allowOverlap: true,
    enableEventAnimations: true,
    columns: [
        {
            type: 'tree',
            text: 'Project',
            field: 'name',
            width: 185,
            sortable: false,
            draggable: false,
        },
    ],

    eventRenderer: ({ eventRecord }) => {
        const { eventType } = eventRecord;

        if (!eventType) return '';

        // These are UI elements meant to mimic
        // the Audere use of Angular web components
        // being injected in the bryntum event render
        // process.  These are not meant as a full
        // representation of the Audere implementation.
        switch (eventType) {
            case 'HourEntry':
                return `<hz-assignment assignmentname="${eventRecord.name}"/>`;
            case 'PhaseSummary':
                return `<hz-phase phasename="${eventRecord.name}"/>`;
            case 'ProjectSummary':
                return `<hz-project projectname="${eventRecord.name}"/>`;
            default:
                // Render the default Bryntum Event UI
                // if we don't have a custom eventType
                return '';
        }
    },

    listeners: {
        /* ************************************************************************
        // To test these different listeners or inspect the event payload
        // just uncomment the listener, refresh, perform the action
        // and check your browser console.
        ***************************************************************************/
        // catchAll: (event) => {
        //     console.log('catch all:', event);
        // },
        // eventDragStart: (event) => {
        //   console.log('eventDragStart:', event);
        // },
        // beforeEventDrag: (event) => {
        //   console.log('beforeEventDrag:', event);
        // },
        // eventDragAbortFinalized: (event) => {
        //     console.log('eventDragAbortFinalized:', event);
        // },
        // eventPartialResize: (event) => {
        //     console.log('eventPartialResize:', event);
        // },
        // eventDragAbort: (event) => {
        //     console.log('eventDragAbort:', event);
        // },
        // afterEventDrop: ({ context }) => {
        //     console.log('afterEventDrop');
        //     console.log('context.valid:', context.valid);
        // },
        // eventDrag: (event) => {
        //     console.log('eventDrag:', event);
        // },
        // eventDragReset: (event) => {
        //     console.log('eventDragReset:', event);
        // },
        // eventDrop: (event) => {
        //     console.log('eventDrop:', event);
        // },
        //beforeEventDropFinalize: (event) => {
        //     console.log('beforeEventDropFinalize:', event);
        //},
        // afterDragCreate: (event) => {
        //   console.log('afterDragCreate:', event);
        // },
        // beforeDragCreateFinalize: (event) => {
        //   console.log('beforeDragCreateFinalize:', event);
        // },
    },

    barMargin: 1,
    rowHeight: 50,

    startDate: new Date(2021, 1, 1),
    endDate: new Date(2024, 1, 7),
    viewPreset: 'hourAndDay',
    features: {
        cellEdit: false,
        cellMenu: false,
        cellTooltip: false,
        columnLines: false,
        dependencyEdit: false,
        eventEdit: false,
        eventMenu: false,
        eventDragSelect: false,
        headerMenu: false,
        pan: false,
        timeAxisHeaderMenu: false,
        scheduleTooltip: false,
        stickyEvents: true,
        dependencies: {
            disabled: true,
        },
        scheduleMenu: {
            items: {
                addEvent: false,
            },
        },
        rowReorder: {
            disabled: false,
            hoverExpandTimeout: 99999999999,
            touchStartDelay: 0,
        },
        columnDragToolbar: true,
        eventTooltip: false,
        eventDragCreate: {
            disabled: false,
            showTooltip: false,
            lockLayout: true,
            showExactResizePosition: true,
        },
        eventDrag: {
            disabled: false,
            constrainDragToResource: true,
            showTooltip: false,
            showExactDropPosition: true,
            dragHelperConfig: {
                touchStartDelay: 0,
            },
        },
        eventResize: {
            disabled: false,
            showExactResizePosition: true,
            showTooltip: false,
            touchHandleSize: 20,
        },
        tree: true,
        resourceTimeRanges: {
            disabled: false,
            tabIndex: null,
        },
        timeRanges: true,
        regionResize: true,
    },
};
